/**
* @license Apache-2.0
*
* Copyright (c) 2022 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

var ndarray = require( '@stdlib/ndarray/ctor' );
var erf = require( '@stdlib/math/base/special/erf' );
var daxpy = require( '@stdlib/blas/base/daxpy' );
var kebabcase = require( '@stdlib/string/kebabcase' );
var randu = require( '@stdlib/random/base/randu' );
var format = require( '@stdlib/string/format' );
var function2string = require( './../lib' );

var fcns = [
	[ 'ndarray', ndarray ],
	[ 'erf', erf ],
	[ 'daxpy', daxpy ],
	[ 'kebabcase', kebabcase ],
	[ 'randu', randu ],
	[ 'format', format ],
	[ 'function2string', function2string ]
];

var i;
for ( i = 0; i < fcns.length; i++ ) {
	console.log( format( 'Function: %s\n\n%s\n', fcns[ i ][ 0 ], function2string( fcns[ i ][ 1 ] ) ) );
}
